pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps
=================================================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps.chromatic_pitch_class_number_to_chromatic_pitch_class_name_with_sharps
